MDSS-package: Modeling Human Dentin Serial Sectioning
Description
MDSS is a package to model microstructures of human tooth dentin and horizontal serial-sectioning of the dentin. The corresponding age range of dentin serial sections, that is used in stable isotope analyses, can be calculated by using this package.
Arguments
Author
Takumi Tsutaya <tsutayatakumi@gmail.com>
Details
Package:
MDSS
Type:
Package
Version:
1.0-1
Date:
2022-08-21
License:
GPL (>= 3)
Function mds models tooth dentin microstructures and horizontal sectioning patterns. The changing dentin growth rates, oblique dentin growth layers, and dentin outer shape are modeled with pre-determined parameters and user's manual adjustments in mds. Function cca calculates corresponding age ranges for each dentin serial sections set with mds. This package adopts S3 class. The detail of mathematical models is described in Tsutaya (in prep).
References
Tsutaya T 2020. Blurred time resolution of tooth dentin serial sections. American Journal of Physical Anthropology 173:748--759. DOI: 10.1002/ajpa.24113.