Learn R Programming

MDSS (version 1.0-1)

unseiji_ST61_C: Stable isotopic data of canine from ST61

Description

This data set gives the stable carbons and nitrogen isotope ratios of dentin serial sections obtained from a human mandibular canine tooth of an individual ST61 (AD 1655--1732) from the Unseiji temple, Japan, reported in Tsutaya et al. (2016).

Usage

unseiji_ST61_C

Arguments

Format

unseiji_ST61_C is a list containing 6 elements.

rt.yy-value for the root tip (i.e., length [mm] of the dentin).
ecjx- and y-coordinates of enamel-cement junction. Dentin horn is placed on the geometric origin, and root tip is placed on the y-axis with a positive value.
section.yy-values for the horizontal sections.
t.start and t.endThe age at the start and end of dentin formation, respectively.
sectionData frame with 18 dentin serial sections (rows) and 3 variables (columns) of assigned midpoint age with equal temporal division, carbon, and nitrogen isotope ratios, named age, d13C, and d15N, respectively.

Details

See detail for Tsutaya et al. (2016).