This data set gives the stable carbons and nitrogen isotope ratios of dentin serial sections obtained from a human mandibular canine tooth of an individual ST61 (AD 1655--1732) from the Unseiji temple, Japan, reported in Tsutaya et al. (2016).
unseiji_ST61_Cunseiji_ST61_C is a list containing 6 elements.
rt.y | y-value for the root tip (i.e., length [mm] of the dentin). |
ecj | x- and y-coordinates of enamel-cement junction. Dentin horn is placed on the geometric origin, and root tip is placed on the y-axis with a positive value. |
section.y | y-values for the horizontal sections. |
t.start and t.end | The age at the start and end of dentin formation, respectively. |
section | Data frame with 18 dentin serial sections (rows) and 3 variables (columns) of assigned midpoint age with equal temporal division, carbon, and nitrogen isotope ratios, named age, d13C, and d15N, respectively. |
See detail for Tsutaya et al. (2016).